@@ -68,6 +68,7 @@ def get_packages(application_path, config=None, returns_only=None,
                                 file_.get('target_path', None),
                                 file_.get('target_extension', None),
                                 file_.get('target_is_executable', None),
+                                file_.get('target_filename', None),
                                 options=config)
         pkg.attach_file(file_['name'] + config.get('name_suffix', ""), file_bin)
         extra_files_list[ file_['name'] ] = file_
@@ -260,7 +261,9 @@ class ApplicationPackage(Package):
         with lcd(self.code_path):
             for step in self.build_assets_steps:
                 local(prefix + step)
-        self.template_options['code_path'] = self.code_path
+        self.template_options['is_python'] = True
+        self.template_options['pyfiles_path'] = os.path.join("/opt", "trebuchet",
+                    self.name, "code")
 
 
     @property
@@ -333,7 +336,8 @@ class PythonEnvironmentPackage(Package):
             for step in self.post_environment_steps:
                 with prefix(". %s/bin/activate" % self.working_path):
                     local(step)
-        self.template_options['venv_path'] = self.target_venv
+        self.template_options['is_python'] = True
+        self.template_options['pyfiles_path'] = self.target_venv
 
 
     def pre_package(self, extra_template_dir=None):
